@@ -1,10 +1,17 @@
 #!/usr/bin/env python
-# Copyright (C) 2011-2014 Swift Navigation Inc.
-# Contact: Fergus Noble <fergus@swiftnav.com>
+# Copyright (C) 2011-2021 Swift Navigation Inc.
+# Contact: https://support.swiftnav.com
 #
 # This source is subject to the license found in the file 'LICENSE' which must
-# be be distributed together with this source. All other rights reserved.
+# be distributed together with this source. All other rights reserved.
 #
 # THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
 # EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
 # WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A PARTICULAR PURPOSE.
+
+from __future__ import absolute_import
+
+try:
+    from ._version import full_version as __version__
+except ImportError:
+    __version__ = "0.0.0"
